@@ -19,9 +19,7 @@
 
 # Re-export public API
 from .api import generate_state
-from .api import get_interfaces
-from .api import get_nameservers
-from .api import get_routes
+from .api import get_current_state
 from .api import is_autoconf_enabled
 from .api import is_dhcp_enabled
 from .api import ovs_netinfo
@@ -42,14 +40,13 @@ from .schema import LinuxBridge
 from .schema import OvsBridgeSchema
 from .schema import OvsDB
 from .schema import Route
+from .schema import RouteRule
 from .schema import Vlan
 
 
 __all__ = [
     'generate_state',
-    'get_interfaces',
-    'get_nameservers',
-    'get_routes',
+    'get_current_state',
     'is_autoconf_enabled',
     'is_dhcp_enabled',
     'ovs_netinfo',
@@ -68,5 +65,6 @@ __all__ = [
     'OvsBridgeSchema',
     'OvsDB',
     'Route',
+    'RouteRule',
     'Vlan',
 ]
